<p align='center'>
    <img src="https://user-images.githubusercontent.com/47505116/215187622-ea13d72c-178d-48bb-aba4-1398abf3347d.png" alt="sushi logo">
</p>

---

<h3 align='center'> sushi is a library that allows you to run functions from other languages without actually translating them</h3>

<h2> how it works? </h2>
<p>Instead of translating code from one language to another, sushi compiles or interprets code creating an executable file or a runnable version of the code so it can be executed and outputed to terminal making it as fast like it would normally be.</p>

<h2> license </h2>
<p> MIT </p>
